@@ -16,23 +16,27 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
 def send_message(webhook, title, text, color):
-    '''Sends an error message to Slack. Not necessarily indicative of a crash.
+    '''Sends a message to Slack.
 
     .. code:: python
     
         from bibtutils.slack.message import send_message
-
-    :type message: :py:class:`str`
-    :param message: a description of the error, included as an 
-        attachment in the Slack message.
+        ...
 
     :type webhook: :py:class:`str`
     :param webhook: a slack webhook in the standard format: 
         ``'https://hooks.slack.com/services/{app_id}/{channel_id}/{hash}'``
+
+    :type title: :py:class:`str`
+    :param title: the title of the message. This will appear above the attachment. 
+        Can be Slack-compatible markdown.
     
-    :type proj_envar: :py:class:`str`
-    :param proj_envar: (Optional) the environment variable to 
-        reference for current GCP project. Defaults to ``'_GOOGLE_PROJECT'``.
+    :type text: :py:class:`str`
+    :param text: the text to be included in the attachment. 
+        Can be Slack-compatible markdown.
+    
+    :type color: :py:class:`str`
+    :param color: the color to use for the Slack attachment border.
     '''
     msg = {
         'blocks': [{
